/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _baseGetTag = require('./dep-a4308f57.js');
var isArray = require('./dep-fcf0662d.js');
var isObjectLike = require('./dep-e4278c54.js');

/** `Object#toString` result references. */
var stringTag = '[object String]';

/**
 * Checks if `value` is classified as a `String` primitive or object.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a string, else `false`.
 * @example
 *
 * _.isString('abc');
 * // => true
 *
 * _.isString(1);
 * // => false
 */
function isString(value) {
  return typeof value == 'string' || !isArray.isArray(value) && isObjectLike.isObjectLike(value) && _baseGetTag.baseGetTag(value) == stringTag;
}

exports.isString = isString;
//# sourceMappingURL=dep-738b4f21.js.map
