/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

var _baseClone = require('./dep-f33eb57d.js');

/** Used to compose bitmasks for cloning. */
var CLONE_DEEP_FLAG = 1,
  CLONE_SYMBOLS_FLAG = 4;

/**
 * This method is like `_.clone` except that it recursively clones `value`.
 *
 * @static
 * @memberOf _
 * @since 1.0.0
 * @category Lang
 * @param {*} value The value to recursively clone.
 * @returns {*} Returns the deep cloned value.
 * @see _.clone
 * @example
 *
 * var objects = [{ 'a': 1 }, { 'b': 2 }];
 *
 * var deep = _.cloneDeep(objects);
 * console.log(deep[0] === objects[0]);
 * // => false
 */
function cloneDeep(value) {
  return _baseClone.baseClone(value, CLONE_DEEP_FLAG | CLONE_SYMBOLS_FLAG);
}

exports.cloneDeep = cloneDeep;
//# sourceMappingURL=dep-f45125c9.js.map
