/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var VueCompositionAPI = require('@vue/composition-api');
var autoComplete_highlightOption = require('./highlight-option.js');
var _common_js_log_log = require('../_common/js/log/log.js');
var hooks_useConfig = require('../hooks/useConfig.js');
var utils_dom = require('../utils/dom.js');
var configProvider_useConfig = require('../config-provider/useConfig.js');
var escapeRegExp = require('../_chunks/dep-67cf27bf.js');
var isFunction = require('../_chunks/dep-ecccff93.js');
require('../_chunks/dep-07fb8c0e.js');
require('../_common/js/global-config/default-config.js');
require('../_common/js/global-config/locale/zh_CN.js');
require('../_chunks/dep-a4a18104.js');
require('@babel/runtime/helpers/typeof');
require('../_chunks/dep-27dd8cc6.js');
require('dayjs');
require('../_chunks/dep-87c765cc.js');
require('../_chunks/dep-75cd6d52.js');
require('../_chunks/dep-b1a02818.js');
require('../_chunks/dep-3d8ab37d.js');
require('../_chunks/dep-a4308f57.js');
require('../_chunks/dep-a4cecac4.js');
require('../_chunks/dep-ab142eaf.js');
require('../_chunks/dep-6ad3de7c.js');
require('../_chunks/dep-e4278c54.js');
require('../_chunks/dep-fcf0662d.js');
require('../_chunks/dep-8b1e056e.js');
require('../_chunks/dep-5db8defc.js');
require('../_chunks/dep-6e4c473c.js');
require('../_chunks/dep-234b7c02.js');
require('../_chunks/dep-a4747856.js');
require('../_chunks/dep-932dd69e.js');
require('../_chunks/dep-9f4caea4.js');
require('../_chunks/dep-dbd838d6.js');
require('../_chunks/dep-b3120c1b.js');
require('../_chunks/dep-68ba2357.js');
require('../_chunks/dep-173eb46c.js');
require('../_chunks/dep-201f7798.js');
require('../_chunks/dep-d3015b4c.js');
require('vue');
require('raf');
require('../utils/easing.js');
require('../_chunks/dep-738b4f21.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _toConsumableArray__default = /*#__PURE__*/_interopDefaultLegacy(_toConsumableArray);
var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty__default["default"](e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var AutoCompleteOptionList = VueCompositionAPI.defineComponent({
  name: "AutoCompleteOptionList",
  props: {
    sizeClassNames: Object,
    value: String,
    size: String,
    options: Array,
    popupVisible: Boolean,
    highlightKeyword: Boolean,
    filterable: Boolean,
    filter: Function,
    empty: [String, Function]
  },
  setup: function setup(props, _ref) {
    var emit = _ref.emit;
    var active = VueCompositionAPI.ref("");
    var classPrefix = hooks_useConfig.usePrefixClass();
    var _useConfig = configProvider_useConfig.useConfig("autoComplete"),
      globalConfig = _useConfig.globalConfig;
    var classes = VueCompositionAPI.computed(function () {
      return "".concat(classPrefix.value, "-select__list");
    });
    var optionClasses = VueCompositionAPI.computed(function () {
      return ["".concat(classPrefix.value, "-select-option"), _defineProperty__default["default"]({}, props.sizeClassNames[props.size], props.size)];
    });
    var tOptions = VueCompositionAPI.computed(function () {
      var options = (props.options || []).map(function (item) {
        var option = {};
        if (typeof item === "string") {
          option = {
            text: item,
            label: item
          };
        } else {
          if (item.text && typeof item.text !== "string") {
            _common_js_log_log["default"].warn("AutoComplete", "`text` must be a string.");
          }
          if (!item.text) {
            if (typeof item.label === "string") {
              option = _objectSpread(_objectSpread({}, item), {}, {
                text: item.label
              });
            } else {
              _common_js_log_log["default"].warn("AutoComplete", "one of `label` and `text` must be a existed string.");
            }
          } else {
            option = item;
          }
        }
        return option;
      });
      if (props.filter) {
        options = options.filter(function (option) {
          return props.filter(props.value, option);
        });
      } else if (props.filterable) {
        var regExp = new RegExp(escapeRegExp.escapeRegExp(props.value), "i");
        options = options.filter(function (item) {
          return regExp.test(item.text);
        });
      }
      return options;
    });
    var onOptionClick = function onOptionClick(e) {
      var liNode = e.target;
      while (liNode && liNode.tagName !== "LI") {
        liNode = liNode.parentNode;
      }
      var keyword = liNode.getAttribute("title");
      active.value = keyword;
      emit("select", keyword, {
        e: e
      });
    };
    var onKeyInnerPress = function onKeyInnerPress(e) {
      if (e.code === "ArrowUp" || e.key === "ArrowUp") {
        var index = tOptions.value.findIndex(function (item) {
          return item.text === active.value;
        });
        var newIndex = index - 1 < 0 ? tOptions.value.length - 1 : index - 1;
        active.value = tOptions.value[newIndex].text;
      } else if (e.code === "ArrowDown" || e.key === "ArrowDown") {
        var _index = tOptions.value.findIndex(function (item) {
          return item.text === active.value;
        });
        var _newIndex = _index + 1 >= tOptions.value.length ? 0 : _index + 1;
        active.value = tOptions.value[_newIndex].text;
      } else if (e.code === "Enter" || e.key === "Enter") {
        emit("select", active.value, {
          e: e
        });
      }
    };
    var addKeyboardListener = function addKeyboardListener() {
      utils_dom.on(document, "keydown", onKeyInnerPress);
    };
    var removeKeyboardListener = function removeKeyboardListener() {
      utils_dom.off(document, "keydown", onKeyInnerPress);
    };
    VueCompositionAPI.watch(function () {
      return props.popupVisible;
    }, function () {
      if (props.popupVisible) {
        addKeyboardListener();
      } else {
        removeKeyboardListener();
      }
    }, {
      immediate: true
    });
    VueCompositionAPI.watch(function () {
      return props.value;
    }, function () {
      if (!props.value) {
        active.value = "";
      }
    }, {
      immediate: true
    });
    VueCompositionAPI.onBeforeUnmount(function () {
      removeKeyboardListener();
    });
    return {
      globalConfig: globalConfig,
      classes: classes,
      classPrefix: classPrefix,
      optionClasses: optionClasses,
      active: active,
      tOptions: tOptions,
      addKeyboardListener: addKeyboardListener,
      removeKeyboardListener: removeKeyboardListener,
      onOptionClick: onOptionClick
    };
  },
  render: function render() {
    var _this = this;
    var h = arguments[0];
    if (!this.tOptions.length) {
      return h("div", {
        "class": "".concat(this.classPrefix, "-auto-complete__panel--empty")
      }, [this.empty || this.globalConfig.empty]);
    }
    return h("ul", {
      "class": this.classes
    }, [this.tOptions.map(function (item) {
      var cls = _toConsumableArray__default["default"](_this.optionClasses);
      if (item.text === _this.active) {
        cls.push("".concat(_this.classPrefix, "-select-option--hover"));
      }
      var labelNode = item.label;
      if (isFunction.isFunction(item.label)) {
        labelNode = item.label(h);
      } else if (_this.$scopedSlots.option) {
        var _this$$scopedSlots$op, _this$$scopedSlots;
        labelNode = (_this$$scopedSlots$op = (_this$$scopedSlots = _this.$scopedSlots).option) === null || _this$$scopedSlots$op === void 0 ? void 0 : _this$$scopedSlots$op.call(_this$$scopedSlots, {
          option: item
        });
      }
      var content = labelNode || item.text;
      return h("li", {
        "key": item.text,
        "class": cls,
        "attrs": {
          "title": item.text
        },
        "on": {
          "click": _this.onOptionClick
        }
      }, [typeof content === "string" && _this.highlightKeyword ? h(autoComplete_highlightOption["default"], {
        "attrs": {
          "content": content,
          "keyword": _this.value
        }
      }) : content]);
    })]);
  }
});

exports["default"] = AutoCompleteOptionList;
//# sourceMappingURL=option-list.js.map
