/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var VueCompositionAPI = require('@vue/composition-api');
var tdesignIconsVue = require('tdesign-icons-vue');
var imageViewer_base_ImageModalIcon = require('./ImageModalIcon.js');
var tooltip_index = require('../../tooltip/index.js');
var configProvider_useConfig = require('../../config-provider/useConfig.js');
var _common_js_inputNumber_largeNumber = require('../../_common/js/input-number/large-number.js');
var hooks_useImagePreviewUrl = require('../../hooks/useImagePreviewUrl.js');
require('@babel/runtime/helpers/defineProperty');
require('../../hooks/useConfig.js');
require('../../_chunks/dep-07fb8c0e.js');
require('../../_common/js/global-config/default-config.js');
require('../../_common/js/global-config/locale/zh_CN.js');
require('../../_chunks/dep-a4a18104.js');
require('@babel/runtime/helpers/typeof');
require('../../_chunks/dep-27dd8cc6.js');
require('dayjs');
require('../../_chunks/dep-87c765cc.js');
require('../../_chunks/dep-75cd6d52.js');
require('../../_chunks/dep-b1a02818.js');
require('../../_chunks/dep-3d8ab37d.js');
require('../../_chunks/dep-ecccff93.js');
require('../../_chunks/dep-a4308f57.js');
require('../../_chunks/dep-a4cecac4.js');
require('../../_chunks/dep-ab142eaf.js');
require('../../_chunks/dep-6ad3de7c.js');
require('../../_chunks/dep-e4278c54.js');
require('../../_chunks/dep-fcf0662d.js');
require('../../_chunks/dep-8b1e056e.js');
require('../../_chunks/dep-5db8defc.js');
require('../../_chunks/dep-6e4c473c.js');
require('../../_chunks/dep-234b7c02.js');
require('../../_chunks/dep-a4747856.js');
require('../../_chunks/dep-932dd69e.js');
require('../../_chunks/dep-9f4caea4.js');
require('../../_chunks/dep-dbd838d6.js');
require('../../_chunks/dep-b3120c1b.js');
require('../../_chunks/dep-68ba2357.js');
require('../../_chunks/dep-173eb46c.js');
require('../../hooks/tnode.js');
require('../../hooks/render-tnode.js');
require('../../_chunks/dep-738b4f21.js');
require('../../_chunks/dep-7c854ec6.js');
require('../../_chunks/dep-eceed11d.js');
require('../../_chunks/dep-201f7798.js');
require('../../_chunks/dep-d3015b4c.js');
require('../../_chunks/dep-f8a85d6a.js');
require('../../_chunks/dep-5b117689.js');
require('../../_chunks/dep-6478392e.js');
require('../../_chunks/dep-47bca35e.js');
require('../../_chunks/dep-a6490a32.js');
require('../../_chunks/dep-3eec664c.js');
require('../../_chunks/dep-eeb2e214.js');
require('../../tooltip/tooltip.js');
require('../../_chunks/dep-ece3c062.js');
require('../../tooltip/props.js');
require('../../popup/props.js');
require('../../popup/popup.js');
require('@popperjs/core');
require('../../utils/dom.js');
require('vue');
require('raf');
require('../../utils/easing.js');
require('../../utils/render-tnode.js');
require('@babel/runtime/helpers/readOnlyError');
require('../../utils/helper.js');
require('@babel/runtime/helpers/objectWithoutProperties');
require('@babel/runtime/helpers/slicedToArray');
require('../../_common/js/utils/setStyle.js');
require('../../popup/container.js');
require('../../config-provider/config-receiver.js');
require('../../utils/mixins.js');
require('../../utils/event.js');
require('../../popup/utils.js');
require('../../_chunks/dep-f3761329.js');
require('../../_chunks/dep-848a5a32.js');
require('../../utils/map-props.js');
require('../../utils/withInstall.js');
require('../../_common/js/log/log.js');
require('../../_chunks/dep-aa0a4aac.js');
require('../../_common/js/upload/utils.js');

var currentImage = {
  type: Object,
  "default": function _default() {
    return {};
  }
};
var TImageViewerUtils = VueCompositionAPI.defineComponent({
  name: "TImageViewerUtils",
  props: {
    scale: Number,
    rotateHandler: Function,
    zoomInHandler: Function,
    zoomOutHandler: Function,
    mirrorHandler: Function,
    resetHandler: Function,
    downloadHandler: Function,
    currentImage: currentImage
  },
  setup: function setup(props) {
    var _useConfig = configProvider_useConfig.useConfig("imageViewer"),
      classPrefix = _useConfig.classPrefix,
      globalConfig = _useConfig.global;
    var imageUrl = VueCompositionAPI.computed(function () {
      return props.currentImage.mainImage;
    });
    var _useImagePreviewUrl = hooks_useImagePreviewUrl.useImagePreviewUrl(imageUrl),
      previewUrl = _useImagePreviewUrl.previewUrl;
    return {
      classPrefix: classPrefix,
      globalConfig: globalConfig,
      previewUrl: previewUrl
    };
  },
  render: function render() {
    var _this = this;
    var h = arguments[0];
    return h("div", {
      "class": "".concat(this.classPrefix, "-image-viewer__utils")
    }, [h("div", {
      "class": "".concat(this.classPrefix, "-image-viewer__utils-content")
    }, [h(tooltip_index.Tooltip, {
      "attrs": {
        "overlayClassName": "".concat(this.classPrefix, "-image-viewer__utils--tip"),
        "content": this.globalConfig.mirrorTipText,
        "destroyOnClose": true,
        "placement": "top",
        "showArrow": true,
        "theme": "default"
      }
    }, [h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "clickHandler": this.mirrorHandler,
        "icon": function icon() {
          return h(tdesignIconsVue.MirrorIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        }
      }
    })]), h(tooltip_index.Tooltip, {
      "attrs": {
        "overlayClassName": "".concat(this.classPrefix, "-image-viewer__utils--tip"),
        "content": this.globalConfig.rotateTipText,
        "destroyOnClose": true,
        "placement": "top",
        "showArrow": true,
        "theme": "default"
      }
    }, [h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "clickHandler": this.rotateHandler,
        "icon": function icon() {
          return h(tdesignIconsVue.RotationIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        }
      }
    })]), h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "icon": function icon() {
          return h(tdesignIconsVue.ZoomOutIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        },
        "clickHandler": this.zoomOutHandler
      }
    }), h(imageViewer_base_ImageModalIcon["default"], {
      "class": "".concat(this.classPrefix, "-image-viewer__utils-scale"),
      "attrs": {
        "size": "medium",
        "label": "".concat(_common_js_inputNumber_largeNumber.largeNumberToFixed(String(this.scale * 100)), "%")
      }
    }), h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "icon": function icon() {
          return h(tdesignIconsVue.ZoomInIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        },
        "clickHandler": this.zoomInHandler
      }
    }), h(tooltip_index.Tooltip, {
      "attrs": {
        "overlayClassName": "".concat(this.classPrefix, "-image-viewer__utils--tip"),
        "content": this.globalConfig.originalSizeTipText,
        "destroyOnClose": true,
        "placement": "top",
        "showArrow": true,
        "theme": "default"
      }
    }, [h("div", {
      "class": "".concat(this.classPrefix, "-image-viewer__modal-icon")
    }, [h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "icon": function icon() {
          return h(tdesignIconsVue.ImageIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        },
        "clickHandler": this.resetHandler
      }
    })])]), this.currentImage.download && h(imageViewer_base_ImageModalIcon["default"], {
      "attrs": {
        "icon": function icon() {
          return h(tdesignIconsVue.DownloadIcon, {
            "attrs": {
              "size": "medium"
            }
          });
        },
        "clickHandler": function clickHandler() {
          _this.downloadHandler(_this.previewUrl);
        }
      }
    })])]);
  }
});

exports["default"] = TImageViewerUtils;
//# sourceMappingURL=ImageViewerUtils.js.map
