/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var VueCompositionAPI = require('@vue/composition-api');
var imageViewer_const = require('./const.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty__default["default"](e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function useDrag(initTransform) {
  var transform = VueCompositionAPI.ref(initTransform);
  var mouseDownHandler = function mouseDownHandler(e) {
    var startX = e.pageX,
      startY = e.pageY;
    var _transform$value = transform.value,
      translateX = _transform$value.translateX,
      translateY = _transform$value.translateY;
    var mouseMoveHandler = function mouseMoveHandler(e2) {
      var pageX = e2.pageX,
        pageY = e2.pageY;
      transform.value = {
        translateX: translateX + pageX - startX,
        translateY: translateY + pageY - startY
      };
    };
    var _mouseUpHandler = function mouseUpHandler() {
      document.removeEventListener("mousemove", mouseMoveHandler);
      document.removeEventListener("mouseup", _mouseUpHandler);
    };
    document.addEventListener("mousemove", mouseMoveHandler);
    document.addEventListener("mouseup", _mouseUpHandler);
  };
  var resetTransform = function resetTransform() {
    transform.value = _objectSpread({}, initTransform);
  };
  return {
    transform: transform,
    mouseDownHandler: mouseDownHandler,
    resetTransform: resetTransform
  };
}
function useMirror() {
  var mirror = VueCompositionAPI.ref(1);
  var onMirror = function onMirror() {
    mirror.value *= -1;
  };
  var resetMirror = function resetMirror() {
    mirror.value = 1;
  };
  return {
    mirror: mirror,
    onMirror: onMirror,
    resetMirror: resetMirror
  };
}
function useScale(imageScale) {
  var _imageScale$value = imageScale.value,
    _imageScale$value$max = _imageScale$value.max,
    max = _imageScale$value$max === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.max : _imageScale$value$max,
    _imageScale$value$min = _imageScale$value.min,
    min = _imageScale$value$min === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.min : _imageScale$value$min,
    _imageScale$value$def = _imageScale$value.defaultScale,
    defaultScale = _imageScale$value$def === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.defaultScale : _imageScale$value$def;
  var scaleVal = Math.min(Math.max(defaultScale, min), max);
  var scale = VueCompositionAPI.ref(scaleVal);
  var setScale = function setScale(newScale) {
    var _imageScale$value2 = imageScale.value,
      _imageScale$value2$ma = _imageScale$value2.max,
      max2 = _imageScale$value2$ma === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.max : _imageScale$value2$ma,
      _imageScale$value2$mi = _imageScale$value2.min,
      min2 = _imageScale$value2$mi === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.min : _imageScale$value2$mi;
    var value = newScale;
    if (newScale < min2) {
      value = min2;
    }
    if (newScale > max2) {
      value = max2;
    }
    scale.value = value;
  };
  var onZoomIn = function onZoomIn() {
    var _imageScale$value$ste = imageScale.value.step,
      step = _imageScale$value$ste === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.step : _imageScale$value$ste;
    setScale(scale.value + step);
  };
  var onZoomOut = function onZoomOut() {
    var _imageScale$value$ste2 = imageScale.value.step,
      step = _imageScale$value$ste2 === void 0 ? imageViewer_const.DEFAULT_IMAGE_SCALE.step : _imageScale$value$ste2;
    setScale(scale.value - step);
  };
  var resetScale = function resetScale() {
    scale.value = scaleVal;
  };
  return {
    scale: scale,
    onZoomIn: onZoomIn,
    onZoomOut: onZoomOut,
    resetScale: resetScale
  };
}
function useRotate() {
  var rotate = VueCompositionAPI.ref(0);
  var ROTATE_DEG = 90;
  var onRotate = function onRotate() {
    rotate.value += ROTATE_DEG;
  };
  var resetRotate = function resetRotate() {
    rotate.value = 0;
  };
  return {
    rotate: rotate,
    onRotate: onRotate,
    resetRotate: resetRotate
  };
}

exports.useDrag = useDrag;
exports.useMirror = useMirror;
exports.useRotate = useRotate;
exports.useScale = useScale;
//# sourceMappingURL=hooks.js.map
