/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

import _defineProperty from '@babel/runtime/helpers/defineProperty';
import Vue from 'vue';
import _Dialog from './dialog.js';
import { getAttach } from '../utils/dom.js';
import { globalConfigSymbol } from '../config-provider/config-provider.js';
import 'lodash-es';
import 'tdesign-icons-vue';
import '../button/index.js';
import '../button/button.js';
import '../loading/index.js';
import '../loading/directive.js';
import '../loading/plugin.js';
import '../loading/loading.js';
import '../loading/icon/gradient.js';
import '../_common/js/loading/circle-adapter.js';
import '../_common/js/utils/setStyle.js';
import '../_common/js/utils/helper.js';
import '@babel/runtime/helpers/toConsumableArray';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@babel/runtime/helpers/slicedToArray';
import '../config-provider/config-receiver.js';
import '../config-provider/context.js';
import '../_common/js/global-config/default-config.js';
import '../_common/js/global-config/locale/zh_CN.js';
import '../_chunks/dep-a883488c.js';
import '@babel/runtime/helpers/typeof';
import '../_chunks/dep-90ffe67f.js';
import 'dayjs';
import '../_chunks/dep-9d1c0d31.js';
import '../config-provider/type.js';
import '../utils/mixins.js';
import '../utils/render-tnode.js';
import '@babel/runtime/helpers/readOnlyError';
import '@vue/composition-api';
import '../utils/transfer-dom.js';
import '../loading/props.js';
import '../config.js';
import 'raf';
import '../utils/easing.js';
import '../utils/withInstall.js';
import './style/css.js';
import '../loading/type.js';
import '../button/props.js';
import '../utils/ripple.js';
import '../button/type.js';
import './actions.js';
import '../_chunks/dep-8db32566.js';
import './props.js';
import '../utils/event.js';
import '../utils/helper.js';
import '../hooks/useDestroyOnClose.js';
import './stack.js';
import '../_common/js/utils/getScrollbarWidth.js';
import '../config-provider/props.js';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var createDialog = function createDialog(props) {
  var options = _objectSpread({}, props);
  var globalOptions = Vue.prototype[globalConfigSymbol];
  var dialog = new _Dialog({
    propsData: _objectSpread(_objectSpread({}, options), {}, {
      onClose: options.onClose || function () {
        dialog.visible = false;
      },
      instanceGlobal: globalOptions === null || globalOptions === void 0 ? void 0 : globalOptions.dialog
    })
  }).$mount();
  dialog.visible = true;
  if (options.className) {
    options.className.split(" ").forEach(function (name) {
      dialog.$el.classList.add(name.trim());
    });
  }
  if (options.style) {
    dialog.$el.style.cssText += options.style;
  }
  var container = getAttach(options.attach);
  if (container) {
    container.appendChild(dialog.$el);
  } else {
    console.error("attach is not exist");
  }
  var dialogNode = {
    show: function show() {
      dialog.visible = true;
    },
    hide: function hide() {
      dialog.visible = false;
    },
    update: function update(options2) {
      Object.assign(dialog, options2);
    },
    destroy: function destroy() {
      dialog.visible = false;
      container.contains(dialog.$el) && container.removeChild(dialog.$el);
    },
    setConfirmLoading: function setConfirmLoading(val) {
      dialog.confirmLoading = val;
    }
  };
  return dialogNode;
};
var confirm = function confirm(props) {
  return createDialog(props);
};
var alert = function alert(props) {
  var options = _objectSpread({}, props);
  options.cancelBtn = null;
  return createDialog(options);
};
var extraApi = {
  confirm: confirm,
  alert: alert
};
var _DialogPlugin = {
  install: function install() {
    Vue.prototype.$dialog = createDialog;
    Object.keys(extraApi).forEach(function (funcName) {
      Vue.prototype.$dialog[funcName] = extraApi[funcName];
    });
  }
};
Object.keys(extraApi).forEach(function (funcName) {
  _DialogPlugin[funcName] = extraApi[funcName];
});
var DialogPlugin = _DialogPlugin;

export { DialogPlugin, DialogPlugin as default };
//# sourceMappingURL=plugin.js.map
