/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { isArray, isNil } from 'lodash-es';
import { defineComponent, ref, provide } from '@vue/composition-api';
import { useTNodeJSX } from '../hooks/tnode.js';
import { usePrefixClass } from '../hooks/useConfig.js';
import props from './props.js';
import descriptionsKey from './const/index.js';
import DescriptionsBody from './descriptions-body.js';
import { renderCustomNode, itemTypeIsProps } from './utils/index.js';
import { ItemsType } from './interface.js';
import { useChildComponentSlots } from '../hooks/slots.js';
import '../hooks/render-tnode.js';
import '../config-provider/useConfig.js';
import '../config-provider/context.js';
import '../_common/js/global-config/default-config.js';
import '../_common/js/global-config/locale/zh_CN.js';
import '../_chunks/dep-84fc5ae7.js';
import '@babel/runtime/helpers/typeof';
import '../_chunks/dep-eb45b5e0.js';
import 'dayjs';
import '../_chunks/dep-653f218a.js';

function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var _Descriptions = defineComponent({
  name: "TDescriptions",
  props: props,
  setup: function setup(props2) {
    var COMPONENT_NAME = usePrefixClass("descriptions");
    var getChildByName = useChildComponentSlots();
    var itemsType = ref(ItemsType.props);
    var renderTNodeJSX = useTNodeJSX();
    var renderTitle = renderTNodeJSX("title");
    var getRows = function getRows() {
      var column = props2.column,
        layout = props2.layout;
      var items = [];
      if (isArray(props2.items)) {
        items = props2.items.map(function (item) {
          return {
            label: renderCustomNode(item.label),
            content: renderCustomNode(item.content),
            span: item.span || 1
          };
        });
        itemsType.value = ItemsType.props;
      } else {
        var slots = getChildByName("TDescriptionsItem");
        if (slots.length !== 0) {
          items = slots;
          itemsType.value = ItemsType.slots;
        }
      }
      if (layout === "vertical") {
        return [items];
      }
      var temp = [];
      var reset = column;
      var res = [];
      items.forEach(function (item, index) {
        var span = 1;
        if (itemTypeIsProps(itemsType.value)) {
          span = isNil(item.span) ? span : item.span;
        } else {
          var propsData = item.componentOptions.propsData || {};
          span = isNil(propsData === null || propsData === void 0 ? void 0 : propsData.span) ? span : propsData.span;
          propsData.span = span;
          Object.assign(item.componentOptions, _objectSpread(_objectSpread({}, item.componentOptions), {}, {
            propsData: propsData
          }));
        }
        if (reset >= span) {
          temp.push(item);
          reset -= span;
        } else {
          res.push(temp);
          temp = [item];
          reset = column - span;
        }
        if (index === items.length - 1) {
          if (itemTypeIsProps(itemsType.value)) {
            Object.assign(item, {
              span: item.span + reset
            });
          } else {
            var _propsData = item.componentOptions.propsData || {};
            _propsData.span += reset;
            Object.assign(item.componentOptions, _objectSpread(_objectSpread({}, item.componentOptions), {}, {
              propsData: _propsData
            }));
          }
          res.push(temp);
        }
      });
      return res;
    };
    provide(descriptionsKey, props2);
    return {
      renderTitle: renderTitle,
      getRows: getRows,
      itemsType: itemsType,
      COMPONENT_NAME: COMPONENT_NAME
    };
  },
  render: function render() {
    var _this = this;
    var h = arguments[0];
    var renderHeader = function renderHeader() {
      return _this.renderTitle ? h("div", {
        "class": "".concat(_this.COMPONENT_NAME, "__header")
      }, [_this.renderTitle]) : "";
    };
    return h("div", {
      "class": this.COMPONENT_NAME
    }, [renderHeader(), h(DescriptionsBody, {
      "attrs": {
        "item-type": this.itemsType,
        "rows": this.getRows()
      }
    })]);
  }
});

export { _Descriptions as default };
//# sourceMappingURL=descriptions.js.map
