/**
 * tdesign v1.11.2
 * (c) 2025 tdesign
 * @license MIT
 */

import { h as helper } from '../_chunks/dep-653f218a.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { defineComponent, ref, computed } from '@vue/composition-api';
import { isString, omit } from 'lodash-es';
import { Loading } from '../loading/index.js';
import _ListItem from './list-item.js';
import props from './props.js';
import { LOAD_MORE, LOADING } from './const.js';
import { usePrefixClass, useCommonClassName } from '../hooks/useConfig.js';
import useListVirtualScroll from './hooks/useListVirtualScroll.js';
import { renderTNodeJSX } from '../utils/render-tnode.js';
import useListItems from './hooks/useListItem.js';
import { useConfig } from '../config-provider/useConfig.js';
import '../loading/directive.js';
import '../loading/plugin.js';
import 'vue';
import '../loading/loading.js';
import '../loading/icon/gradient.js';
import '../_common/js/loading/circle-adapter.js';
import '../_common/js/utils/setStyle.js';
import '../_common/js/utils/helper.js';
import '@babel/runtime/helpers/toConsumableArray';
import '@babel/runtime/helpers/objectWithoutProperties';
import '@babel/runtime/helpers/slicedToArray';
import '../config-provider/config-receiver.js';
import '../config-provider/context.js';
import '../_common/js/global-config/default-config.js';
import '../_common/js/global-config/locale/zh_CN.js';
import '../_chunks/dep-84fc5ae7.js';
import '@babel/runtime/helpers/typeof';
import '../_chunks/dep-eb45b5e0.js';
import 'dayjs';
import '../utils/mixins.js';
import '../utils/dom.js';
import 'raf';
import '../utils/easing.js';
import '../utils/transfer-dom.js';
import '../loading/props.js';
import '../config.js';
import '@babel/runtime/helpers/readOnlyError';
import '../utils/withInstall.js';
import './list-item-props.js';
import '../hooks/useVirtualScrollNew.js';
import '../hooks/useResizeObserver.js';
import '../utils/helper.js';

var _List = defineComponent({
  name: "TList",
  props: props,
  setup: function setup(props2, _ref) {
    var emit = _ref.emit;
    var listRef = ref();
    var _useConfig = useConfig("list"),
      globalConfig = _useConfig.globalConfig;
    var componentName = usePrefixClass("list");
    var _useCommonClassName = useCommonClassName(),
      SIZE = _useCommonClassName.SIZE;
    var _useListItems = useListItems(),
      listItems = _useListItems.listItems;
    var listClass = computed(function () {
      return ["".concat(componentName.value), SIZE.value[props2.size], _defineProperty(_defineProperty(_defineProperty({}, "".concat(componentName.value, "--split"), props2.split), "".concat(componentName.value, "--stripe"), props2.stripe), "".concat(componentName.value, "--vertical-action"), props2.layout === "vertical")];
    });
    var loadingClass = computed(function () {
      return isString(props2.asyncLoading) && ["loading", "load-more"].includes(props2.asyncLoading) ? "".concat(componentName.value, "__load ").concat(componentName.value, "__load--").concat(props2.asyncLoading) : "".concat(componentName.value, "__load");
    });
    var _useListVirtualScroll = useListVirtualScroll(props2.scroll, listRef, listItems),
      virtualConfig = _useListVirtualScroll.virtualConfig,
      cursorStyle = _useListVirtualScroll.cursorStyle,
      listStyle = _useListVirtualScroll.listStyle,
      isVirtualScroll = _useListVirtualScroll.isVirtualScroll,
      onInnerVirtualScroll = _useListVirtualScroll.onInnerVirtualScroll;
    var handleScroll = function handleScroll(e) {
      var _props2$onScroll;
      var listElement = e.target;
      var scrollTop = listElement.scrollTop,
        scrollHeight = listElement.scrollHeight,
        clientHeight = listElement.clientHeight;
      if (isVirtualScroll.value) onInnerVirtualScroll(e);
      var scrollParams = {
        e: e,
        scrollTop: scrollTop,
        scrollBottom: scrollHeight - clientHeight - scrollTop
      };
      emit("scroll", scrollParams);
      (_props2$onScroll = props2.onScroll) === null || _props2$onScroll === void 0 || _props2$onScroll.call(props2, scrollParams);
    };
    var handleLoadMore = function handleLoadMore(e) {
      var _props2$onLoadMore;
      if (isString(props2.asyncLoading) && props2.asyncLoading !== LOAD_MORE) return;
      emit("load-more", {
        e: e
      });
      (_props2$onLoadMore = props2.onLoadMore) === null || _props2$onLoadMore === void 0 || _props2$onLoadMore.call(props2, {
        e: e
      });
    };
    return {
      componentName: componentName,
      listClass: listClass,
      loadingClass: loadingClass,
      handleScroll: handleScroll,
      handleLoadMore: handleLoadMore,
      listRef: listRef,
      globalConfig: globalConfig,
      virtualConfig: virtualConfig,
      cursorStyle: cursorStyle,
      listStyle: listStyle,
      isVirtualScroll: isVirtualScroll
    };
  },
  render: function render() {
    var _this = this;
    var h = arguments[0];
    var isVirtualScroll = this.isVirtualScroll,
      cursorStyle = this.cursorStyle,
      listStyle = this.listStyle,
      componentName = this.componentName,
      globalConfig = this.globalConfig,
      virtualConfig = this.virtualConfig;
    var propsHeaderContent = renderTNodeJSX(this, "header");
    var propsFooterContent = renderTNodeJSX(this, "footer");
    var renderLoading = function renderLoading() {
      if (_this.asyncLoading && isString(_this.asyncLoading)) {
        if (_this.asyncLoading === LOADING) {
          return h("div", [h(Loading), h("span", [globalConfig.loadingText])]);
        }
        if (_this.asyncLoading === LOAD_MORE) {
          return h("span", [globalConfig.loadingMoreText]);
        }
      }
      return renderTNodeJSX(_this, "asyncLoading");
    };
    return h("div", {
      "class": this.listClass,
      "on": {
        "scroll": this.handleScroll
      },
      "ref": "listRef",
      "style": isVirtualScroll ? "position:relative" : void 0
    }, [propsHeaderContent ? h("div", {
      "class": "".concat(componentName, "__header")
    }, [propsHeaderContent]) : null, isVirtualScroll ? h("div", [h("div", {
      "style": cursorStyle
    }), h("ul", {
      "class": "".concat(componentName, "__inner"),
      "style": listStyle
    }, [virtualConfig.visibleData.value.map(function (item) {
      return h(_ListItem, helper([{}, omit(item, "slots"), {
        "scopedSlots": {
          "default": item.slots
        }
      }]));
    })])]) : h("ul", {
      "class": "".concat(componentName, "__inner")
    }, [renderTNodeJSX(this, "default")]), propsFooterContent ? h("div", {
      "class": "".concat(componentName, "__footer")
    }, [propsFooterContent]) : null, h("div", {
      "class": this.loadingClass,
      "on": {
        "click": this.handleLoadMore
      }
    }, [renderLoading()])]);
  }
});

export { _List as default };
//# sourceMappingURL=list.js.map
